@@ -1,7 +1,7 @@
 #' @title Chunks API
 #' @noRd
 #'
-#' @author Rolf Simoes, \email{rolf.simoes@@inpe.br}
+#' @author Rolf Simoes, \email{rolfsimoes@@gmail.com}
 #'
 #' @description
 #' A chunk is a tibble of rectangular regions defining a matrix and
@@ -44,45 +44,49 @@ NULL
 .chunks_create <- function(block, overlap, image_size, image_bbox) {
     # Generate all starting block points (col, row)
     chunks <- tidyr::expand_grid(
-        col = seq(1, .ncols(image_size), .ncols(block)),
-        row = seq(1, .nrows(image_size), .nrows(block))
+        col = seq(1L, .ncols(image_size), .ncols(block)),
+        row = seq(1L, .nrows(image_size), .nrows(block))
     )
     # Adjust col and row to do overlap
-    chunks[["col"]] <- .as_int(pmax(1, .col(chunks) - overlap))
-    chunks[["row"]] <- .as_int(pmax(1, .row(chunks) - overlap))
+    chunks[["col"]] <- .as_int(pmax(1L, .col(chunks) - overlap))
+    chunks[["row"]] <- .as_int(pmax(1L, .row(chunks) - overlap))
     # Adjust ncols and nrows to do overlap
     chunks[["ncols"]] <- .as_int(
-        pmin(.ncols(image_size),
-             .col(chunks) + .ncols(block) + overlap - 1) - .col(chunks) + 1
+        pmin(
+            .ncols(image_size),
+            .col(chunks) + .ncols(block) + overlap - 1L
+        ) - .col(chunks) + 1L
     )
     chunks[["nrows"]] <- .as_int(
-        pmin(.nrows(image_size),
-             .row(chunks) + .nrows(block) + overlap - 1) - .row(chunks) + 1
+        pmin(
+            .nrows(image_size),
+            .row(chunks) + .nrows(block) + overlap - 1L
+        ) - .row(chunks) + 1L
     )
     # Chunk of entire image
     entire_image <- c(image_size, image_bbox)
     # Prepare a raster as template to crop bbox
-    t_obj <- .chunks_as_raster(chunk = entire_image, nlayers = 1)
+    t_obj <- .chunks_as_raster(chunk = entire_image, nlayers = 1L)
     # Generate chunks' bbox
     chunks <- slider::slide_dfr(chunks, function(chunk) {
         # Crop block from template
-        r_obj <- .raster_crop_metadata(r_obj = t_obj, block = .block(chunk))
+        rast <- .raster_crop_metadata(rast = t_obj, block = .block(chunk))
         # Add bbox information
-        .xmin(chunk) <- .raster_xmin(r_obj = r_obj)
-        .xmax(chunk) <- .raster_xmax(r_obj = r_obj)
-        .ymin(chunk) <- .raster_ymin(r_obj = r_obj)
-        .ymax(chunk) <- .raster_ymax(r_obj = r_obj)
-        .crs(chunk) <- .raster_crs(r_obj = r_obj)
+        .xmin(chunk) <- .raster_xmin(rast = rast)
+        .xmax(chunk) <- .raster_xmax(rast = rast)
+        .ymin(chunk) <- .raster_ymin(rast = rast)
+        .ymax(chunk) <- .raster_ymax(rast = rast)
+        .crs(chunk) <- .raster_crs(rast = rast)
         chunk
     })
     # Overlapping support
     chunks[["overlap"]] <- .as_int(overlap)
     # Chunk size without overlap
     chunks[["crop_ncols"]] <- .as_int(pmin(
-        .ncols(image_size) - .col(chunks) + 1, .ncols(block)
+        .ncols(image_size) - .col(chunks) + 1L, .ncols(block)
     ))
     chunks[["crop_nrows"]] <- .as_int(pmin(
-        .nrows(image_size) - .row(chunks) + 1, .nrows(block)
+        .nrows(image_size) - .row(chunks) + 1L, .nrows(block)
     ))
     # Return chunks
     chunks
@@ -94,14 +98,14 @@ NULL
 #' @return  An empty raster object based on the on a chunk.
 .chunks_as_raster <- function(chunk, nlayers) {
     .raster_new_rast(
-        nrows = .nrows(chunk)[[1]],
-        ncols = .ncols(chunk)[[1]],
-        xmin = .xmin(chunk)[[1]],
-        xmax = .xmax(chunk)[[1]],
-        ymin = .ymin(chunk)[[1]],
-        ymax = .ymax(chunk)[[1]],
+        nrows = .nrows(chunk)[[1L]],
+        ncols = .ncols(chunk)[[1L]],
+        xmin = .xmin(chunk)[[1L]],
+        xmax = .xmax(chunk)[[1L]],
+        ymin = .ymin(chunk)[[1L]],
+        ymax = .ymax(chunk)[[1L]],
         nlayers = nlayers,
-        crs = .crs(chunk)[[1]]
+        crs = .crs(chunk)[[1L]]
     )
 }
 #' @title Remove overlaps from chunks
@@ -111,32 +115,32 @@ NULL
 .chunks_no_overlap <- function(chunks) {
     # Generate blocks
     cropped <- tibble::tibble(
-        col = .as_int(pmin(chunks[["overlap"]] + 1, .col(chunks))),
-        row = .as_int(pmin(chunks[["overlap"]] + 1, .row(chunks)))
+        col = .as_int(pmin(chunks[["overlap"]] + 1L, .col(chunks))),
+        row = .as_int(pmin(chunks[["overlap"]] + 1L, .row(chunks)))
     )
     # Adjust blocks size
     .ncols(cropped) <- pmin(
-        .ncols(chunks) - .col(cropped) + 1, .as_int(chunks[["crop_ncols"]])
+        .ncols(chunks) - .col(cropped) + 1L, .as_int(chunks[["crop_ncols"]])
     )
     .nrows(cropped) <- pmin(
-        .nrows(chunks) - .row(cropped) + 1, .as_int(chunks[["crop_nrows"]])
+        .nrows(chunks) - .row(cropped) + 1L, .as_int(chunks[["crop_nrows"]])
     )
     # Generate bbox for each chunk
     cropped <- slider::slide2_dfr(chunks, cropped, function(chunk, crop) {
         # Prepare a raster as template to crop bbox
-        t_obj <- .chunks_as_raster(chunk = chunk, nlayers = 1)
+        t_obj <- .chunks_as_raster(chunk = chunk, nlayers = 1L)
         # Crop block from template
-        r_obj <- .raster_crop_metadata(r_obj = t_obj, block = .block(crop))
+        rast <- .raster_crop_metadata(rast = t_obj, block = .block(crop))
         # Add bbox information
-        .xmin(crop) <- .raster_xmin(r_obj = r_obj)
-        .xmax(crop) <- .raster_xmax(r_obj = r_obj)
-        .ymin(crop) <- .raster_ymin(r_obj = r_obj)
-        .ymax(crop) <- .raster_ymax(r_obj = r_obj)
-        .crs(crop) <- .raster_crs(r_obj = r_obj)
+        .xmin(crop) <- .raster_xmin(rast = rast)
+        .xmax(crop) <- .raster_xmax(rast = rast)
+        .ymin(crop) <- .raster_ymin(rast = rast)
+        .ymax(crop) <- .raster_ymax(rast = rast)
+        .crs(crop) <- .raster_crs(rast = rast)
         crop
     })
     # Finish cropped chunks
-    cropped[["overlap"]] <- 0
+    cropped[["overlap"]] <- 0L
     cropped[["crop_ncols"]] <- chunks[["crop_ncols"]]
     cropped[["crop_nrows"]] <- chunks[["crop_nrows"]]
     # Return cropped chunks
@@ -160,7 +164,7 @@ NULL
     # transform chunk to bbox
     chunks_sf <- .bbox_as_sf(.bbox(chunks, by_feature = TRUE))
     # remove chunks within mask
-    chunks[!.within(chunks_sf, mask),]
+    chunks[!.within(chunks_sf, mask), ]
 }
 #' @title Crop chunk geometries by mask
 #' @noRd
@@ -181,31 +185,33 @@ NULL
 #' @returns  A tibble with filtered segments
 .chunks_filter_segments <- function(chunks, tile, output_dir) {
     # Read segments from tile
-    segments <- .segments_read_vec(tile)
+    segs <- .segments_read_vec(tile)
     # Transform each chunk in sf object
     sf_chunks <- .bbox_as_sf(
         .bbox(chunks, by_feature = TRUE, default_crs = .tile_crs(tile))
     )
     # Find segments in chunks
-    idx_intersects <- sf::st_intersects(sf_chunks, segments, sparse = TRUE) |>
-                      purrr::imap_dfr(
-                          ~dplyr::as_tibble(.x) |> dplyr::mutate(id = .y)
-                      ) |>
-                      dplyr::distinct(.data[["value"]], .keep_all = TRUE) |>
-                      dplyr::group_by(.data[["id"]]) |>
-                      tidyr::nest() |>
-                      tibble::deframe()
+    idx_intersects <- sf::st_intersects(sf_chunks, segs, sparse = TRUE) |>
+        purrr::imap_dfr(
+            ~ dplyr::as_tibble(.x) |> dplyr::mutate(id = .y)
+        ) |>
+        dplyr::distinct(.data[["value"]], .keep_all = TRUE) |>
+        dplyr::group_by(.data[["id"]]) |>
+        tidyr::nest() |>
+        tibble::deframe()
+    idx_positions <- as.integer(names(idx_intersects))
+    chunks <- chunks[idx_positions, ]
     chunks[["segments"]] <- purrr::map(seq_along(idx_intersects), function(i) {
         idx <- unname(as.vector(idx_intersects[[i]]))
-        idx <- idx[[1]]
+        idx <- idx[[1L]]
         block_file <- .file_block_name(
             pattern = "chunk_seg",
             block = .block(chunks[i, ]),
             output_dir = output_dir,
             ext = "gpkg"
         )
-        .vector_write_vec(segments[idx, ], block_file)
-        return(block_file)
+        .vector_write_vec(segs[idx, ], block_file, append = TRUE)
+        block_file
     })
-    return(chunks)
+    chunks
 }
