@@ -2,16 +2,15 @@
 #' @name .classify_tile
 #' @keywords internal
 #' @noRd
-#' @author Rolf Simoes, \email{rolf.simoes@@inpe.br}
+#' @author Rolf Simoes, \email{rolfsimoes@@gmail.com}
 #' @author Gilberto Camara, \email{gilberto.camara@@inpe.br}
+#' @author Felipe Carvalho, \email{felipe.carvalho@@inpe.br}
+#' @author Felipe Carlos, \email{efelipecarlos@@gmail.com}
 #'
-#' @description Classifies a block of data using multicores. It breaks
-#' the data into horizontal blocks and divides them between the available cores.
-#'
-#' Reads data using terra, cleans the data for NAs and missing values.
-#' The clean data is stored in a data table with the time instances
-#' for all pixels of the block. The algorithm then classifies data on
-#' an year by year basis. For each year, extracts the sub-blocks for each band.
+#' @description Classifies a block of data using multicores, breaking
+#' the data into blocks and divides them between the available cores.
+#' The size of the blocks is optimized to account for COG files and
+#' for the balance of multicores and memory size.
 #'
 #' After all cores process their blocks, it joins the result and then writes it
 #' in the classified images for each corresponding year.
@@ -44,18 +43,18 @@
                            version,
                            verbose,
                            progress) {
-    # Output file
+    # Define the name of the output file
     out_file <- .file_derived_name(
         tile = tile,
         band = out_band,
         version = version,
         output_dir = output_dir
     )
-    # Resume feature
+    # If output file exists, builds a
+    # probability cube directly from the file
+    # and does not reprocess input
     if (file.exists(out_file)) {
-        if (.check_messages()) {
-            .check_recovery(out_file)
-        }
+        .check_recovery()
         probs_tile <- .tile_derived_from_file(
             file = out_file,
             band = out_band,
@@ -66,18 +65,19 @@
         )
         return(probs_tile)
     }
-    # Show initial time for tile classification
+    # Initial time for tile classification
     tile_start_time <- .tile_classif_start(
         tile = tile,
         verbose = verbose
     )
-    # Create chunks as jobs
+    # Create chunks to be allocated to jobs in parallel
     chunks <- .tile_chunks_create(
         tile = tile,
-        overlap = 0,
+        overlap = 0L,
         block = block
     )
-    # By default, update_bbox is FALSE
+    # Create a variable to control updating of bounding box
+    # by default, update_bbox is FALSE
     update_bbox <- FALSE
     if (.has(exclusion_mask)) {
         # How many chunks there are in tile?
@@ -96,21 +96,21 @@
         update_bbox <- nrow(chunks) != nchunks
     }
     if (.has(roi)) {
-        # How many chunks still available ?
+        # How many chunks do we need to process?
         nchunks <- nrow(chunks)
-        # Intersecting chunks with ROI
+        # Intersect chunks with ROI
         chunks <- .chunks_filter_spatial(
             chunks = chunks,
             roi = roi
         )
-        # Should bbox of resulting tile be updated?
+        # Update bbox to account for ROI
         update_bbox <- nrow(chunks) != nchunks
     }
-    # Process jobs in parallel
+    # Process jobs in parallel - one job per chunk
     block_files <- .jobs_map_parallel_chr(chunks, function(chunk) {
-        # Job block
+        # Retrive block to be processed
         block <- .block(chunk)
-        # Block file name
+        # Create a temporary block file name
         block_file <- .file_block_name(
             pattern = .file_pattern(out_file),
             block = block,
@@ -120,7 +120,7 @@
         if (.raster_is_valid(block_file)) {
             return(block_file)
         }
-        # Read and preprocess values
+        # Read and preprocess values from files
         values <- .classify_data_read(
             tile = tile,
             block = block,
@@ -133,46 +133,43 @@
         # Get mask of NA pixels
         na_mask <- C_mask_na(values)
         # Fill with zeros remaining NA pixels
-        values <- C_fill_na(values, 0)
-        # Used to check values (below)
+        values <- C_fill_na(values, 0.0)
+        # Define control variable to check for correct termination
         input_pixels <- nrow(values)
-        # Log here
+        # Start log file
         .debug_log(
             event = "start_block_data_classification",
             key = "model",
             value = .ml_class(ml_model)
         )
         # Apply the classification model to values
-        values <- ml_model(values)
-        # normalize and calibrate the values
-        values <- .ml_normalize(ml_model, values)
+        # Uses the closure created by sits_train
+        values <-  ml_model(values)
+        # Normalize and calibrate the values
+        # Perform softmax for torch models,
+        values <- .ml_normalize(values, ml_model)
         # Are the results consistent with the data input?
         .check_processed_values(
             values = values,
             input_pixels = input_pixels
         )
-        # Log
+        # Log end of block
         .debug_log(
             event = "end_block_data_classification",
             key = "model",
             value = .ml_class(ml_model)
         )
-        # Prepare probability to be saved
+        # Obtain configuration parameters for probability cube
         band_conf <- .conf_derived_band(
             derived_class = "probs_cube",
             band = out_band
         )
-        offset <- .offset(band_conf)
-        if (.has(offset) && offset != 0) {
-            values <- values - offset
-        }
-        scale <- .scale(band_conf)
-        if (.has(scale) && scale != 1) {
-            values <- values / scale
-        }
+        # Apply scaling to classified values
+        band_scale <- .scale(band_conf)
+        values <- values / band_scale
         # Put NA back in the result
         values[na_mask, ] <- NA
-        # Log
+        # Log start of block saving
         .debug_log(
             event = "start_block_data_save",
             key = "file",
@@ -188,7 +185,7 @@
             missing_value = .miss_value(band_conf),
             crop_block = chunk[["mask"]]
         )
-        # Log
+        # Log end of block saving
         .debug_log(
             event = "end_block_data_save",
             key = "file",
@@ -200,17 +197,16 @@
         block_file
     }, progress = progress)
     # Merge blocks into a new probs_cube tile
-    # Check if there is a ROI
     # If ROI exists, blocks are merged to a different directory
     # than output_dir, which is used to save the final cropped version
     merge_out_file <- out_file
     if (.has(roi)) {
         merge_out_file <- .file_derived_name(
-                tile = tile,
-                band = out_band,
-                version = version,
-                output_dir = file.path(output_dir, ".sits")
-            )
+            tile = tile,
+            band = out_band,
+            version = version,
+            output_dir = file.path(output_dir, ".sits")
+        )
     }
     probs_tile <- .tile_derived_merge_blocks(
         file = merge_out_file,
@@ -224,14 +220,15 @@
     )
     # Clean GPU memory allocation
     .ml_gpu_clean(ml_model)
-    # if there is a ROI, we need to crop
+    # if there is a ROI, crop the probability cube
     if (.has(roi)) {
         probs_tile_crop <- .crop(
             cube = probs_tile,
             roi = roi,
             output_dir = output_dir,
-            multicores = 1,
-            progress = FALSE)
+            multicores = 1L,
+            progress = progress
+        )
         unlink(.fi_paths(.fi(probs_tile)))
     }
     # show final time for classification
@@ -240,30 +237,27 @@
         start_time = tile_start_time,
         verbose = verbose
     )
-    # Return probs tile or cropped version
-    if (.has(roi))
-        return(probs_tile_crop)
-    else
-        return(probs_tile)
+    # Return probs tile (cropped version in case of ROI)
+    if (.has(roi)) {
+        probs_tile_crop
+    } else {
+        probs_tile
+    }
 }
 
 #' @title Classify a chunk of raster data  using multicores
-#' @name .classify_tile
+#' @name .classify_vector_tile
 #' @keywords internal
 #' @noRd
-#' @author Rolf Simoes, \email{rolf.simoes@@inpe.br}
+#' @author Rolf Simoes, \email{rolfsimoes@@gmail.com}
 #' @author Gilberto Camara, \email{gilberto.camara@@inpe.br}
+#' @author Felipe Carvalho, \email{felipe.carvalho@@inpe.br}
+#' @author Felipe Carlos, \email{efelipecarlos@@gmail.com}
 #'
-#' @description Classifies a block of data using multicores. It breaks
-#' the data into horizontal blocks and divides them between the available cores.
-#'
-#' Reads data using terra, cleans the data for NAs and missing values.
-#' The clean data is stored in a data table with the time instances
-#' for all pixels of the block. The algorithm then classifies data on
-#' an year by year basis. For each year, extracts the sub-blocks for each band.
-#'
-#' After all cores process their blocks, it joins the result and then writes it
-#' in the classified images for each corresponding year.
+#' @description Classifies a block of data using multicores. Breaks
+#' the data into blocks and divides them between the available cores.
+#' After all cores process their blocks,
+#' joins the result and then writes it.
 #'
 #' @param  tile       Single tile of a data cube.
 #' @param  bands      Bands to extract time series
@@ -274,8 +268,8 @@
 #' @param  filter_fn  Smoothing filter function to be applied to the data.
 #' @param  impute_fn  Imputation function to remove NA values.
 #' @param  n_sam_pol  Number of samples per polygon to be read
-#'                    for POLYGON or MULTIPOLYGON shapefiles or sf objects.
-#' @param  multicores Number of cores to be used for classification
+#'                    for POLYGON or MULTIPOLYGON vector objects.
+#' @param  multicores Number of cores for classification
 #' @param  gpu_memory Memory available in GPU (default = NULL)
 #' @param  version    Version of result.
 #' @param  output_dir Output directory.
@@ -296,7 +290,7 @@
                                   version,
                                   output_dir,
                                   progress) {
-    # Output file
+    # Define output vector file name and extension
     out_file <- .file_derived_name(
         tile = tile,
         band = "probs",
@@ -304,11 +298,10 @@
         output_dir = output_dir,
         ext = "gpkg"
     )
-    # Resume feature
+    # Checks if output file already exists
+    # If TRUE, returns the existing file and avoids re-processing
     if (.segments_is_valid(out_file)) {
-        if (.check_messages()) {
-            .check_recovery(out_file)
-        }
+        .check_recovery()
         # Create tile based on template
         probs_tile <- .tile_segments_from_file(
             file = out_file,
@@ -323,22 +316,16 @@
     # Create chunks as jobs
     chunks <- .tile_chunks_create(
         tile = tile,
-        overlap = 0,
+        overlap = 0L,
         block = block
     )
     # By default, update_bbox is FALSE
     if (.has(roi)) {
-        # How many chunks there are in tile?
-        nchunks <- nrow(chunks)
         # Intersecting chunks with ROI
         chunks <- .chunks_filter_spatial(
             chunks = chunks,
             roi = roi
         )
-        # Should bbox of resulting tile be updated?
-        update_bbox <- nrow(chunks) != nchunks
-    } else {
-        update_bbox <- FALSE
     }
     # Filter segments that intersects with each chunk
     chunks <- .chunks_filter_segments(
@@ -346,12 +333,13 @@
         tile = tile,
         output_dir = output_dir
     )
+    # Define that chunks will be deleted upon exit
     on.exit(unlink(unlist(chunks[["segments"]])))
     # Process jobs in parallel
     block_files <- .jobs_map_parallel_chr(chunks, function(chunk) {
-        # Job block
+        # Retrieve block from chunk
         block <- .block(chunk)
-        # Block file name
+        # Define block file name
         block_file <- .file_block_name(
             pattern = .file_pattern(out_file),
             block = block,
@@ -362,7 +350,8 @@
         if (.segments_is_valid(block_file)) {
             return(block_file)
         }
-        # Extract segments time series
+        # Extract time series from segments
+        # Number of time series per segment is defined by n_sam_pol
         segments_ts <- .segments_poly_read(
             tile = tile,
             bands = bands,
@@ -371,15 +360,21 @@
             n_sam_pol = n_sam_pol,
             impute_fn = impute_fn
         )
-        # Classify segments
+        # Deal with NO DATA cases (e.g., cloudy areas)
+        if (nrow(segments_ts) == 0L) {
+            return("")
+        }
+        # Classify times series
+        # This is the same function called to classify
+        # individual time series (with an extra polygon_id)
         segments_ts <- .classify_ts(
             samples = segments_ts,
             ml_model = ml_model,
             filter_fn = filter_fn,
             impute_fn = impute_fn,
-            multicores = 1,
+            multicores = 1L,
             gpu_memory = gpu_memory,
-            progress = FALSE
+            progress = progress
         )
         # Join probability values with segments
         segments_ts <- .segments_join_probs(
@@ -394,14 +389,18 @@
         # Free memory
         gc()
         # Return block file
-        return(block_file)
+        block_file
     }, progress = progress)
-    # Read all segments
-    segments_ts <- purrr::map(block_files, .vector_read_vec)
-    segments_ts <- dplyr::bind_rows(segments_ts)
-    # Write all segments
+    # Remove empty block files
+    block_files <- purrr::discard(block_files, Negate(nzchar))
+    # Read segments from all block files
+    segments_ts <- block_files |>
+        purrr::map(.vector_read_vec) |>
+        dplyr::bind_rows()
+    # Write segments to a vector data cube
     .vector_write_vec(v_obj = segments_ts, file_path = out_file)
-    # Create tile based on template
+    # Create probability vector tile
+    # joining vector and raster components of data cube
     probs_tile <- .tile_segments_from_file(
         file = out_file,
         band = "probs",
@@ -410,18 +409,20 @@
         vector_class = "probs_vector_cube",
         update_bbox = FALSE
     )
-    # Remove file block
+    # Remove file blocks
     unlink(block_files)
     # Return probability vector tile
-    return(probs_tile)
+    probs_tile
 }
 
-#' @title Read a block of values retrieved from a set of raster images
+#' @title Read a block of values from a set of raster images
 #' @name  .classify_data_read
 #' @keywords internal
 #' @noRd
+#' @author Rolf Simoes, \email{rolfsimoes@@gmail.com}
 #' @author Gilberto Camara, \email{gilberto.camara@@inpe.br}
-#' @author Rolf Simoes, \email{rolf.simoes@@inpe.br}
+#' @author Felipe Carvalho, \email{felipe.carvalho@@inpe.br}
+#' @author Felipe Carlos, \email{efelipecarlos@@gmail.com}
 #'
 #' @param  tile            Input tile to read data.
 #' @param  block           Bounding box in (col, row, ncols, nrows).
@@ -436,7 +437,7 @@
     # For cubes that have a time limit to expire (MPC cubes only)
     tile <- .cube_token_generator(tile)
     # Read and preprocess values of cloud
-    # Get cloud values (NULL if not exists)
+    # Get cloud values (NULL if data does not exist)
     cloud_mask <- .tile_cloud_read_block(
         tile = tile,
         block = block
@@ -467,19 +468,6 @@
         if (.has(filter_fn)) {
             values <- filter_fn(values)
         }
-        # Normalize values for old version model classifiers that
-        #   do not normalize values itself
-        # Models trained after version 1.2 do this automatically before
-        #   classification
-        stats <- .ml_stats_0(ml_model) # works for old models only!!
-        if (.has(stats)) {
-            q02 <- .stats_0_q02(stats, band)
-            q98 <- .stats_0_q98(stats, band)
-            if (.has(q02) && .has(q98)) {
-                # Use C_normalize_data_0 to process old version of normalization
-                values <- C_normalize_data_0(values, q02, q98)
-            }
-        }
         # Log
         .debug_log(
             event = "end_block_data_process",
@@ -487,7 +475,7 @@
             value = band
         )
         # Return values
-        return(as.data.frame(values))
+        as.data.frame(values)
     })
     # Read and preprocess values of each base band
     values_base <- purrr::map(base_bands, function(band) {
@@ -498,7 +486,7 @@
             block = block
         )
         # Return values
-        return(as.data.frame(values_base))
+        as.data.frame(values_base)
     })
     # Combine two lists
     values <- c(values, values_base)
@@ -515,16 +503,19 @@
     # Return values
     values
 }
-#' @title Classify a distances tibble using machine learning models
+#' @title Classify a sits tibble using machine learning models
 #' @name .classify_ts
 #' @keywords internal
 #' @noRd
+#' @author Rolf Simoes, \email{rolfsimoes@@gmail.com}
 #' @author Gilberto Camara, \email{gilberto.camara@@inpe.br}
+#' @author Felipe Carvalho, \email{felipe.carvalho@@inpe.br}
+#' @author Felipe Carlos, \email{efelipecarlos@@gmail.com}
 #'
 #' @description Returns a sits tibble with the results of the ML classifier.
 #'
-#' @param  samples    a tibble with sits samples
-#' @param  ml_model   model trained by \code{\link[sits]{sits_train}}.
+#' @param  samples    Tibble with sits samples
+#' @param  ml_model   Model trained by \code{\link[sits]{sits_train}}.
 #' @param  filter_fn  Smoothing filter to be applied (if desired).
 #' @param  impute_fn  Imputation function (to remove NA)
 #' @param  multicores number of threads to process the time series.
@@ -570,10 +561,10 @@
         samples = .ml_samples(ml_model)
     )
     # Split long time series of samples in a set of small time series
-    if (length(class_info[["dates_index"]][[1]]) > 1) {
+    if (length(class_info[["dates_index"]][[1L]]) > 1L) {
         splitted <- .samples_split(
             samples = samples,
-            split_intervals = class_info[["dates_index"]][[1]]
+            split_intervals = class_info[["dates_index"]][[1L]]
         )
         pred <- .predictors(
             samples = splitted,
@@ -592,21 +583,22 @@
         )
     }
     # choose between GPU and CPU
-    if (.torch_gpu_classification() && .ml_is_torch_model(ml_model))
+    if (.torch_gpu_classification() && .ml_is_torch_model(ml_model)) {
         prediction <- .classify_ts_gpu(
             pred = pred,
             ml_model = ml_model,
             gpu_memory = gpu_memory
         )
-    else
+    } else {
         prediction <- .classify_ts_cpu(
             pred = pred,
             ml_model = ml_model,
             multicores = multicores,
             progress = progress
         )
+    }
     # Store the result in the input data
-    if (length(class_info[["dates_index"]][[1]]) > 1) {
+    if (length(class_info[["dates_index"]][[1L]]) > 1L) {
         prediction <- .tibble_prediction_multiyear(
             data = samples,
             class_info = class_info,
@@ -619,13 +611,20 @@
         )
     }
     # Set result class and return it
-    .set_class(x = prediction, "predicted", class(samples))
+    prediction <- .set_class(
+        x = prediction, "predicted",
+        class(samples)
+    )
+    prediction
 }
 #' @title Classify predictors using CPU
 #' @name .classify_ts_cpu
 #' @keywords internal
 #' @noRd
+#' @author Rolf Simoes, \email{rolfsimoes@@gmail.com}
 #' @author Gilberto Camara, \email{gilberto.camara@@inpe.br}
+#' @author Felipe Carvalho, \email{felipe.carvalho@@inpe.br}
+#' @author Felipe Carlos, \email{efelipecarlos@@gmail.com}
 #'
 #' @description Returns a sits tibble with the results of the ML classifier.
 #'
@@ -638,7 +637,6 @@
                              ml_model,
                              multicores,
                              progress) {
-
     # Divide samples predictors in chunks to parallel processing
     parts <- .pred_create_partition(
         pred = pred,
@@ -646,14 +644,14 @@
     )
     # Do parallel process
     prediction <- .jobs_map_parallel_dfr(parts, function(part) {
-        # Get predictors of a given partition
-        pred_part <- .pred_part(part)
-        # Get predictors features to classify
-        values <- .pred_features(pred_part)
-        # Classify
-        values <- ml_model(values)
-        # normalize and calibrate values
-        values <- .ml_normalize(ml_model, values)
+        # Extract predictors of a given partition
+        # Extract features to classify
+        # Classify, normalize and calibrate value
+        values <- part |>
+            .pred_part() |>
+            .pred_features() |>
+            ml_model() |>
+            .ml_normalize(ml_model)
         # Extract columns
         values_columns <- colnames(values)
         # Transform classification results
@@ -662,16 +660,18 @@
         # (e.g., with spaces, icons)
         colnames(values) <- values_columns
         # Return classification
-        return(values)
+        values
     }, progress = progress)
-
-    return(prediction)
+    prediction
 }
 #' @title Classify predictors using GPU
 #' @name .classify_ts_gpu
 #' @keywords internal
 #' @noRd
+#' @author Rolf Simoes, \email{rolfsimoes@@gmail.com}
 #' @author Gilberto Camara, \email{gilberto.camara@@inpe.br}
+#' @author Felipe Carvalho, \email{felipe.carvalho@@inpe.br}
+#' @author Felipe Carlos, \email{efelipecarlos@@gmail.com}
 #'
 #' @description Returns a sits tibble with the results of the ML classifier.
 #'
@@ -683,9 +683,7 @@
                              ml_model,
                              gpu_memory) {
     # estimate size of GPU memory required (in GB)
-    pred_size <- nrow(pred) * ncol(pred) * 8 / 1e+09
-    # include processing bloat
-    # pred_size <- pred_size * .conf("processing_bloat")
+    pred_size <- nrow(pred) * ncol(pred) * 8.0 / 1000000000.0
     # estimate how should we partition the predictors
     num_parts <- ceiling(pred_size / gpu_memory)
     # Divide samples predictors in chunks to parallel processing
@@ -695,13 +693,14 @@
     )
     prediction <- slider::slide_dfr(parts, function(part) {
         # Get predictors of a given partition
-        pred_part <- .pred_part(part)
         # Get predictors features to classify
-        values <- .pred_features(pred_part)
         # Classify
-        values <- ml_model(values)
         # normalize and calibrate values
-        values <- .ml_normalize(ml_model, values)
+        values <- part |>
+            .pred_part() |>
+            .pred_features() |>
+            ml_model() |>
+            .ml_normalize(ml_model)
         # Extract columns
         values_columns <- colnames(values)
         # Transform classification results
@@ -711,15 +710,15 @@
         colnames(values) <- values_columns
         # Clean GPU memory
         .ml_gpu_clean(ml_model)
-        return(values)
+        values
     })
-    return(prediction)
+    prediction
 }
 #' @title Start recording processing time
 #' @name .classify_verbose_start
 #' @keywords internal
 #' @noRd
-#' @author Gilberto Camara, \email{gilberto.camara@@inpe.br}
+#' @author Rolf Simoes, \email{rolfsimoes@@gmail.com}
 #' @description Prints the block size and computes
 #' start time for processing
 #'
@@ -727,19 +726,20 @@
 #' @param  block   block size
 #' @return start time for processing
 .classify_verbose_start <- function(verbose, block) {
-    start_time <- Sys.time()
     if (verbose) {
-        msg <- paste0(.conf("messages", ".verbose_block_size"), " ",
-                      .nrows(block), " x ", .ncols(block))
+        msg <- paste0(
+            .conf("messages", ".verbose_block_size"), " ",
+            .nrows(block), " x ", .ncols(block)
+        )
         message(msg)
     }
-    return(start_time)
+    Sys.time()
 }
 #' @title End recording processing time
 #' @name .classify_verbose_end
 #' @keywords internal
 #' @noRd
-#' @author Gilberto Camara, \email{gilberto.camara@@inpe.br}
+#' @author Rolf Simoes, \email{rolfsimoes@@gmail.com}
 #' @description Prints the processing time
 #' @param  verbose TRUE/FALSE
 #' @param  start_time   initial processing time
@@ -749,8 +749,9 @@
         end_time <- Sys.time()
         message("")
         message(.conf("messages", ".verbose_task_end"), end_time)
-        message(.conf("messages", ".verbose_task_elapsed"),
-                format(round(end_time - start_time, digits = 2))
+        message(
+            .conf("messages", ".verbose_task_elapsed"),
+            format(round(end_time - start_time, digits = 2L))
         )
     }
 }
