@@ -1,7 +1,7 @@
 #' @title  Comparison functions
 #' @noRd
 #'
-#' @author Rolf Simoes, \email{rolf.simoes@@inpe.br}
+#' @author Rolf Simoes, \email{rolfsimoes@@gmail.com}
 #' @author Felipe Carvalho, \email{felipe.carvalho@@inpe.br}
 #'
 #' @description
@@ -15,27 +15,27 @@ NULL
 #' @title Compare if `x` is equal to `y` considering a tolerance
 #' @noRd
 #' @returns A logical value
-.is_eq <- function(x, y, tolerance = 0) {
+.is_eq <- function(x, y, tolerance = 0.0) {
     .check_set_caller(".is_eq")
-    .check_that(tolerance >= 0)
+    .check_that(tolerance >= 0.0)
     # Compute result and return
-    all(abs(x - y) <= tolerance[[1]])
+    all(abs(x - y) <= tolerance)
 }
 #' @title Compare if `x` is less than `y` considering a tolerance
 #' @noRd
 #' @returns A logical value
-.is_lt <- function(x, y, tolerance = 0) {
+.is_lt <- function(x, y, tolerance = 0.0) {
     .check_set_caller(".is_lt")
-    .check_that(tolerance >= 0)
+    .check_that(tolerance >= 0.0)
     # Compute result and return
-    all(abs(y - x) > tolerance[[1]])
+    all(abs(y - x) > tolerance)
 }
 #' @title Compare if `x` is greater than `y` considering a tolerance
 #' @noRd
 #' @returns A logical value
-.is_gt <- function(x, y, tolerance = 0) {
+.is_gt <- function(x, y, tolerance = 0.0) {
     .check_set_caller(".is_gt")
-    .check_that(tolerance >= 0)
+    .check_that(tolerance >= 0.0)
     # Compute result and return
-    all(abs(x - y) > tolerance[[1]])
+    all(abs(x - y) > tolerance)
 }
