@@ -1,6 +1,6 @@
 #' @title Create a closure for calling functions with and without data
 #' @name .factory_function
-#' @author Rolf Simoes, \email{rolf.simoes@@inpe.br}
+#' @author Rolf Simoes, \email{rolfsimoes@@gmail.com}
 #' @author Gilberto Camara, \email{gilberto.camara@@inpe.br}
 #' @keywords internal
 #' @noRd
@@ -32,5 +32,5 @@
         # ...otherwise compute the result on the input data
         result <- fun(data)
     }
-    return(result)
+    result
 }
