@@ -1,5 +1,5 @@
-# ---- open search utilities ----
 #' @title Prepare Open Search feature as STAC Item (Compatible with `rstac`).
+#' @author Felipe Carlos, \email{efelipecarlos@@gmail.com}
 #' @keywords internal
 #' @noRd
 #'
@@ -26,6 +26,7 @@
 }
 
 #' @title Prepare Open Search features as STAC Items (Compatible with `rstac`).
+#' @author Felipe Carlos, \email{efelipecarlos@@gmail.com}
 #' @keywords internal
 #' @noRd
 #'
@@ -51,6 +52,7 @@
 }
 
 #' @title Query scenes available in the CDSE Open Search.
+#' @author Felipe Carlos, \email{efelipecarlos@@gmail.com}
 #' @keywords internal
 #' @noRd
 #'
@@ -77,7 +79,7 @@
                                     start_date, end_date,
                                     bbox,
                                     paginate = TRUE,
-                                    limit = 1000, ...) {
+                                    limit = 1000L, ...) {
     .check_set_caller(".opensearch_cdse_client")
     # CDSE Open Search configurations
     cdse_opensearch_base_url <- .conf(
@@ -89,16 +91,15 @@
     cdse_opensearch_endpoint <- "search.json"
     # Create the Open Search endpoint for the collection
     # Selected by user
-    collection_url <- paste(
+    collection_url <- file.path(
         cdse_opensearch_base_url,
         collection,
-        cdse_opensearch_endpoint,
-        sep = "/"
+        cdse_opensearch_endpoint
     )
     # Define features to save content from Open Search
-    features_result <- c()
+    features_result <- NULL
     # Define variables to support the pagination in the Open Search
-    current_page <- 1
+    current_page <- 1L
     is_to_fetch_more <- TRUE
     # Prepare bounding box in the format required by Open Search
     if (!is.null(bbox)) {
@@ -120,8 +121,8 @@
         # Get raw content from Open Search API
         response <- .get_request(url = collection_url, query = query)
         .check_int_parameter(.response_status(response),
-                             min = 200,
-                             max = 200
+            min = 200L,
+            max = 200L
         )
         # Extract data from the response
         page_data <- .response_content(response)
@@ -143,9 +144,8 @@
     }
     .opensearch_as_stac_items(features_result)
 }
-
-# ---- open search specializations ----
 #' @title Extract `tile` from Open Search Items.
+#' @author Felipe Carlos, \email{efelipecarlos@@gmail.com}
 #' @keywords internal
 #' @noRd
 #' @description
@@ -159,18 +159,8 @@
     UseMethod(".opensearch_cdse_extract_tile")
 }
 
-#' @keywords internal
-#' @noRd
-#' @export
-.opensearch_cdse_extract_tile.S2MSI2A <- function(items) {
-    items_titles <- rstac::items_reap(items, field = c("properties", "title"))
-    purrr::map(items_titles, function(item_title) {
-        tile_name <- stringr::str_split(item_title, "_")[[1]][6]
-        tile_name <- stringr::str_replace(tile_name, "T", "")
-        tile_name
-    })
-}
-
+#' @title Extract `tile` from Open Search Items for Sentinel-1 RTC
+#' @author Felipe Carlos, \email{efelipecarlos@@gmail.com}
 #' @keywords internal
 #' @noRd
 #' @export
@@ -178,7 +168,8 @@
     "NoTilingSystem"
 }
 
-#' @title Search data using CDSE Open Search.
+#' @title Search data using CDSE Open Search
+#' @author Felipe Carlos, \email{efelipecarlos@@gmail.com}
 #' @keywords internal
 #' @noRd
 #' @description
@@ -210,39 +201,12 @@
                                     platform,
                                     orbit = NULL,
                                     paginate = TRUE,
-                                    limit = 1000, ...) {
+                                    limit = 1000L, ...) {
     UseMethod(".opensearch_cdse_search")
 }
 
-#' @keywords internal
-#' @noRd
-#' @export
-.opensearch_cdse_search.S2MSI2A <- function(product_type,
-                                            source, collection,
-                                            start_date, end_date,
-                                            bbox,
-                                            platform = NULL,
-                                            orbit = NULL,
-                                            paginate = TRUE,
-                                            limit = 1000, ...) {
-    .check_set_caller(".opensearch_cdse_search_s2msi2a")
-    # Search!
-    .opensearch_cdse_client(
-        product_type,
-        source,
-        collection,
-        start_date,
-        end_date,
-        bbox,
-        paginate,
-        limit,
-        status = "ONLINE",
-        instrument = "MSI",
-        platform = platform,
-        processingLevel = "S2MSI2A"
-    )
-}
-
+#' @title Search data using CDSE Open Search for Sentinel-1 RTC
+#' @author Felipe Carlos, \email{efelipecarlos@@gmail.com}
 #' @keywords internal
 #' @noRd
 #' @export
@@ -252,11 +216,13 @@
                                         bbox,
                                         platform = NULL,
                                         orbit = NULL,
-                                        paginate = TRUE, limit = 1000, ...) {
+                                        paginate = TRUE, limit = 1000L, ...) {
     .check_set_caller(".opensearch_cdse_search_rtc")
     # check orbit
-    orbits <- .conf("sources", source, "collections", collection, "orbits")
-    .check_chr_within(x = orbit, within = orbits)
+    if (!is.null(orbit)) {
+        orbits <- .conf("sources", source, "collections", collection, "orbits")
+        .check_chr_within(x = orbit, within = orbits)
+    }
     # Search!
     .opensearch_cdse_client(
         product_type,
