@@ -1,4 +1,3 @@
-
 #' @title Extract temporal pattern from samples data.
 #' @name .pattern_temporal_median
 #' @keywords internal
@@ -11,7 +10,9 @@
             ts_median <- dplyr::bind_rows(data[["time_series"]]) |>
                 dplyr::group_by(.data[["Index"]]) |>
                 dplyr::summarize(dplyr::across(dplyr::everything(),
-                                               stats::median, na.rm = TRUE)) |>
+                    stats::median,
+                    na.rm = TRUE
+                )) |>
                 dplyr::select(-.data[["Index"]])
 
             ts_median["label"] <- name
