@@ -9,8 +9,6 @@
 #' @param start_date      Start date for the data set.
 #' @param end_date        End date for the data set.
 #' @param n_shp_pol       Number of samples per polygon to be read.
-#' @param shp_id          ID attribute which contains the label
-#'                        (for POLYGON or MULTIPOLYGON shapefile).
 #' @param sampling_type   Spatial sampling type: random, hexagonal,
 #'                        regular, or Fibonacci.
 #' @return                A sits tibble with samples to be retrieved.
@@ -21,7 +19,6 @@
                              start_date,
                              end_date,
                              n_shp_pol,
-                             shp_id,
                              sampling_type) {
     # set caller to show in errors
     .check_set_caller(".shp_get_samples")
@@ -34,19 +31,16 @@
     )
     # Get the points to be read
     samples <- .sf_to_tibble(
-        sf_object  = sf_shape,
+        sf_object = sf_shape,
         label_attr = shp_attr,
-        label      = label,
-        n_sam_pol  = n_shp_pol,
-        pol_id     = shp_id,
+        label = label,
+        n_sam_pol = n_shp_pol,
         sampling_type = sampling_type,
         start_date = start_date,
-        end_date   = end_date
+        end_date = end_date
     )
-
-    class(samples) <- c("sits", class(samples))
-
-    return(samples)
+    # set class and return
+    .set_class(samples, "sits", class(samples))
 }
 
 #' @title Check the validity of the shape file and return an sf object
@@ -68,17 +62,17 @@
     # read the shapefile
     sf_shape <- sf::read_sf(shp_file)
     # postcondition - is the shape file valid?
-    .check_that(nrow(sf_shape) > 0)
+    .check_that(.has(sf_shape))
 
     # get the geometry type
-    geom_type <- sf::st_geometry_type(sf_shape)[[1]]
+    geom_type <- sf::st_geometry_type(sf_shape)[[1L]]
 
     # postcondition - are all geometries compatible?
     .check_that(all(sf::st_geometry_type(sf_shape) == geom_type))
     # postcondition - can the function deal with the geometry_type?
-    .check_that(as.character(geom_type) %in%  .conf("sf_geom_types_supported"))
+    .check_that(as.character(geom_type) %in% .conf("sf_geom_types_supported"))
     # postcondition - is the shape attribute valid?
     .check_shp_attribute(sf_shape, shp_attr)
-
-    return(sf_shape)
+    # return
+    sf_shape
 }
