@@ -29,10 +29,9 @@
     # if more than 2 times items pagination are found the progress bar
     # is displayed
     progress <- rstac::items_matched(items_info) >
-        2 * .conf("rstac_pagination_limit")
+        2L * .conf("rstac_pagination_limit")
     # check documentation mode
-    progress <- .check_documentation(progress)
-
+    progress <- .message_progress(progress)
     # fetching all the metadata and updating to upper case instruments
     items_info <- rstac::items_fetch(items = items_info, progress = progress)
     # checks if the items returned any items
@@ -54,10 +53,10 @@
 #' @return An object referring the images of a sits cube.
 #' @export
 `.source_items_new.deafrica_cube_sentinel-2-l2a` <- function(source, ...,
-                                                     collection,
-                                                     stac_query,
-                                                     tiles = NULL,
-                                                     platform = NULL) {
+                                                             collection,
+                                                             stac_query,
+                                                             tiles = NULL,
+                                                             platform = NULL) {
     # set caller to show in errors
     .check_set_caller(".source_items_new")
     # check platform
@@ -72,10 +71,12 @@
     if (!is.null(tiles)) {
         roi <- .s2_mgrs_to_roi(tiles)
         stac_query[["params"]][["intersects"]] <- NULL
-        stac_query[["params"]][["bbox"]] <- c(roi[["lon_min"]],
-                                              roi[["lat_min"]],
-                                              roi[["lon_max"]],
-                                              roi[["lat_max"]])
+        stac_query[["params"]][["bbox"]] <- c(
+            roi[["lon_min"]],
+            roi[["lat_min"]],
+            roi[["lon_max"]],
+            roi[["lat_max"]]
+        )
     } else {
         roi <- .stac_intersects_as_bbox(stac_query)
         stac_query[["params"]][["intersects"]] <- NULL
@@ -86,15 +87,16 @@
     items_info <- rstac::items_fetch(items = items_info, progress = FALSE)
     # filter items
     items_info <- rstac::items_filter(items_info,
-                                      filter_fn = function(feature) {
-        lgl_res <- TRUE
+        filter_fn = function(feature) {
+            lgl_res <- TRUE
 
-        if (!is.null(platform)) {
-            lgl_res <- feature[["properties"]][["platform"]] == platform
+            if (!is.null(platform)) {
+                lgl_res <- feature[["properties"]][["platform"]] == platform
+            }
+
+            lgl_res
         }
-
-        lgl_res
-    })
+    )
     # check results
     .check_stac_items(items_info)
     # done
@@ -103,13 +105,12 @@
 #' @keywords internal
 #' @noRd
 #' @export
-`.source_items_new.deafrica_cube_sentinel-1-rtc` <- function(
-                                                         source, ...,
-                                                         collection,
-                                                         stac_query,
-                                                         tiles = NULL,
-                                                         platform = NULL,
-                                                         orbit = NULL) {
+`.source_items_new.deafrica_cube_sentinel-1-rtc` <- function(source, ...,
+                                                             collection,
+                                                             stac_query,
+                                                             tiles = NULL,
+                                                             platform = NULL,
+                                                             orbit = NULL) {
     # set caller to show in errors
     .check_set_caller(".source_items_new")
     # check orbits
@@ -127,10 +128,12 @@
     if (!is.null(tiles)) {
         roi <- .s2_mgrs_to_roi(tiles)
         stac_query[["params"]][["intersects"]] <- NULL
-        stac_query[["params"]][["bbox"]] <- c(roi[["lon_min"]],
-                                              roi[["lat_min"]],
-                                              roi[["lon_max"]],
-                                              roi[["lat_max"]])
+        stac_query[["params"]][["bbox"]] <- c(
+            roi[["lon_min"]],
+            roi[["lat_min"]],
+            roi[["lon_max"]],
+            roi[["lat_max"]]
+        )
     } else {
         roi <- .stac_intersects_as_bbox(stac_query)
         stac_query[["params"]][["intersects"]] <- NULL
@@ -141,18 +144,19 @@
     items_info <- rstac::items_fetch(items = items_info, progress = FALSE)
     # filter items
     items_info <- rstac::items_filter(items_info,
-                                      filter_fn = function(feature) {
-        lgl_res <- feature[["properties"]][["sat:orbit_state"]]     == orbit &&
-                   feature[["properties"]][["sar:instrument_mode"]] == "IW"  &&
-                   feature[["properties"]][["sar:frequency_band"]]  == "C"
+        filter_fn = function(feature) {
+            lgl_res <- feature[["properties"]][["sat:orbit_state"]] == orbit &&
+                feature[["properties"]][["sar:instrument_mode"]] == "IW" &&
+                feature[["properties"]][["sar:frequency_band"]] == "C"
 
-        if (!is.null(platform)) {
-            lgl_res <- lgl_res &&
-                       feature[["properties"]][["platform"]] == platform
+            if (!is.null(platform)) {
+                lgl_res <- lgl_res &&
+                    feature[["properties"]][["platform"]] == platform
+            }
+
+            lgl_res
         }
-
-        lgl_res
-    })
+    )
     # check results
     .check_stac_items(items_info)
     # done
@@ -165,7 +169,7 @@
                                                                 collection,
                                                                 cube,
                                                                 tiles) {
-    return(cube)
+    cube
 }
 #' @keywords internal
 #' @noRd
@@ -187,8 +191,9 @@
     # Digital Earth Africa provides some products with the `properties.datetime`
     # property `null`. In those cases, it is required to use other date
     # parameter available
-    if (is.null(item_date))
+    if (is.null(item_date)) {
         item_date <- item[[c("properties", "start_datetime")]]
+    }
 
     suppressWarnings(
         lubridate::as_date(item_date)
@@ -200,11 +205,11 @@
 `.source_items_tile.deafrica_cube_rainfall-chirps-daily` <-
     function(source, items, ..., collection = NULL) {
         rep("NoTilingSystem", rstac::items_length(items))
-}
+    }
 #' @keywords internal
 #' @noRd
 #' @export
 `.source_items_tile.deafrica_cube_rainfall-chirps-monthly` <-
     function(source, items, ..., collection = NULL) {
-    rep("NoTilingSystem", rstac::items_length(items))
-}
+        rep("NoTilingSystem", rstac::items_length(items))
+    }
