@@ -6,7 +6,24 @@
 #' @author Charlotte Pelletier, \email{charlotte.pelletier@@univ-ubs.fr}
 #'
 #' @description Implementation of Light Temporal Attention Encoder (L-TAE)
-#' for satellite image time series
+#' for satellite image time series. This is a lightweight version of the
+#' temporal attention encoder proposed by Garnot et al. For the TAE,
+#' please see \code{\link[sits]{sits_tae}}.
+#'
+#' TAE is a simplified version of the well-known self-attention architeture
+#' which is used in large language models.
+#' Its modified self-attention scheme that uses the input
+#' embeddings as values. TAE defines a single master query for each sequence,
+#' computed from the temporal average of the queries. This master query is compared
+#' to the sequence of keys to produce a single attention mask
+#' used to weight the temporal mean of values into a single feature vector.
+#'
+#' The lightweight version of TAE further simplifies the TAE model.
+#' It defines master query of each head as a model parameter instead
+#' of the results of a linear layer, as is done it TAE.
+#' The authors argue that such simplification reduces the number of parameters,
+#' while the lack of flexibility is compensated by the larger number of available heads.
+#'
 #'
 #' @note
 #' \code{sits} provides a set of default values for all classification models.
@@ -18,12 +35,12 @@
 #'
 #' This function is based on the paper by Vivien Garnot referenced below
 #' and code available on github at
-#' https://github.com/VSainteuf/lightweight-temporal-attention-pytorch
+#' \url{https://github.com/VSainteuf/lightweight-temporal-attention-pytorch}
 #' If you use this method, please cite the original TAE and the LTAE paper.
 #'
 #' We also used the code made available by Maja Schneider in her work with
 #' Marco Körner referenced below and available at
-#' https://github.com/maja601/RC2020-psetae.
+#' \url{https://github.com/maja601/RC2020-psetae}.
 #'
 #' @references
 #' Vivien Garnot, Loic Landrieu, Sebastien Giordano, and Nesrine Chehata,
@@ -31,7 +48,7 @@
 #' and Temporal Self-Attention",
 #' 2020 Conference on Computer Vision and Pattern Recognition.
 #' pages 12322-12331.
-#' DOI: 10.1109/CVPR42600.2020.01234
+#' \doi{10.1109/CVPR42600.2020.01234}
 #'
 #' Vivien Garnot, Loic Landrieu,
 #' "Lightweight Temporal Self-Attention  for Classifying
@@ -42,7 +59,7 @@
 #' "[Re] Satellite Image Time Series Classification
 #' with Pixel-Set Encoders and Temporal Self-Attention."
 #' ReScience C 7 (2), 2021.
-#' DOI: 10.5281/zenodo.4835356
+#' \doi{10.5281/zenodo.4835356}
 #'
 #' @param samples            Time series with the training samples
 #'                           (tibble of class "sits").
@@ -68,6 +85,7 @@
 #'                           training stops.
 #' @param min_delta	         Minimum improvement in loss function
 #'                           to reset the patience counter.
+#' @param seed               Seed for random values.
 #' @param verbose            Verbosity mode (TRUE/FALSE). Default is FALSE.
 #'
 #' @return A fitted model to be used for classification of data cubes.
@@ -120,6 +138,7 @@ sits_lighttae <- function(samples = NULL,
                           lr_decay_rate = 1.0,
                           patience = 20L,
                           min_delta = 0.01,
+                          seed = NULL,
                           verbose = FALSE) {
     # set caller for error msg
     .check_set_caller("sits_lighttae")
@@ -150,6 +169,8 @@ sits_lighttae <- function(samples = NULL,
             patience = patience, min_delta = min_delta,
             verbose = verbose
         )
+        # Other pre-conditions:
+        .check_int_parameter(seed, allow_null = TRUE)
 
         # Check opt_hparams
         # Get parameters list and remove the 'param' parameter
@@ -203,8 +224,11 @@ sits_lighttae <- function(samples = NULL,
             dim = c(n_samples_test, n_times, n_bands)
         )
         test_y <- unname(code_labels[.pred_references(test_samples)])
+        # Create a torch seed (we define a new variable to allow users
+        # to access this seed number from the model environment)
+        torch_seed <- .torch_seed(seed)
         # Set torch seed
-        torch::torch_manual_seed(sample.int(10000L, 1L))
+        torch::torch_manual_seed(torch_seed)
         # Define the L-TAE architecture
         light_tae_model <- torch::nn_module(
             classname = "model_ltae",
@@ -254,7 +278,7 @@ sits_lighttae <- function(samples = NULL,
                 # by .ml_normalize.torch_model function
             }
         )
-        # torch 12.0 with luz not working with Apple MPS
+        # verify if GPU is available
         cpu_train <- .torch_cpu_train()
         # Train the model using luz
         torch_model <-
@@ -307,7 +331,6 @@ sits_lighttae <- function(samples = NULL,
             # Verifies if torch package is installed
             .check_require_packages("torch")
             # Set torch threads to 1
-            # Note: function does not work on MacOS
             suppressWarnings(torch::torch_set_num_threads(1L))
             # Unserialize model
             torch_model[["model"]] <- .torch_unserialize_model(serialized_model)
