@@ -39,7 +39,8 @@ usethis::use_build_ignore("revdep/")
 devtools::revdep()
 library(revdepcheck)
 # In another session
-id <- rstudioapi::terminalExecute("Rscript -e 'revdepcheck::revdep_check(num_workers = 4)'")
+id <- rstudioapi::terminalExecute
+    ("Rscript -e 'revdepcheck::revdep_check(num_workers = 4)'")
 rstudioapi::terminalKill(id)
 # See outputs
 revdep_details(revdep = "pkg")
