@@ -275,8 +275,6 @@ test_that("FCN-LSTM model", {
         sits_classify(
             data = point_ndvi,
             ml_model = model,
-            gpu_memory = 2,
-            memsize = 4,
             progress = FALSE
         )
 
