@@ -23,7 +23,7 @@ test_that("Regularizing cubes from AWS, and extracting samples from them", {
     expect_error(.check_cube_is_regular(s2_cube_open))
     expect_true(all(sits_bands(s2_cube_open) %in% c("B8A", "CLOUD")))
 
-    timelines <-  suppressWarnings(sits_timeline(s2_cube_open))
+    timelines <- suppressWarnings(sits_timeline(s2_cube_open))
     expect_equal(length(timelines), 2)
     expect_equal(length(timelines[["20LKP"]]), 6)
     expect_equal(length(timelines[["20LLP"]]), 13)
@@ -33,7 +33,7 @@ test_that("Regularizing cubes from AWS, and extracting samples from them", {
         suppressWarnings(dir.create(dir_images))
     }
 
-    expect_warning(rg_cube <- sits_regularize(
+    rg_cube <- suppressWarnings(sits_regularize(
         cube = s2_cube_open,
         output_dir = dir_images,
         res = 240,
@@ -42,12 +42,6 @@ test_that("Regularizing cubes from AWS, and extracting samples from them", {
         progress = FALSE
     ))
 
-    tile_bbox <- .tile_bbox(rg_cube)
-    expect_equal(.tile_nrows(rg_cube), 458)
-    expect_equal(.tile_ncols(rg_cube), 458)
-    expect_equal(tile_bbox$xmax, 309780, tolerance = 1e-1)
-    expect_equal(tile_bbox$xmin, 199980, tolerance = 1e-1)
-
     tile_fileinfo <- .fi(rg_cube)
 
     expect_equal(nrow(tile_fileinfo), 2)
@@ -69,7 +63,7 @@ test_that("Regularizing cubes from AWS, and extracting samples from them", {
     # Retrieving data
 
     csv_file <- system.file("extdata/samples/samples_amazonia.csv",
-                            package = "sits"
+        package = "sits"
     )
 
     # read sample information from CSV file and put it in a tibble
@@ -90,8 +84,7 @@ test_that("Regularizing cubes from AWS, and extracting samples from them", {
 test_that("Creating Landsat cubes from MPC", {
     bbox <- c(
         xmin = -48.28579, ymin = -16.05026,
-        xmax = -47.30839, ymax = -15.50026,
-        crs = 4326
+        xmax = -47.30839, ymax = -15.50026
     )
 
     landsat_cube <- .try(
@@ -100,6 +93,7 @@ test_that("Creating Landsat cubes from MPC", {
                 source = "MPC",
                 collection = "LANDSAT-C2-L2",
                 roi = bbox,
+                crs = 4326,
                 bands = c("NIR08", "CLOUD"),
                 start_date = as.Date("2008-07-18"),
                 end_date = as.Date("2008-10-23"),
@@ -125,7 +119,7 @@ test_that("Creating Landsat cubes from MPC", {
     if (!dir.exists(output_dir)) {
         dir.create(output_dir)
     }
-    expect_warning(rg_landsat <- sits_regularize(
+    rg_landsat <- suppressWarnings(sits_regularize(
         cube = landsat_cube,
         output_dir = output_dir,
         res = 240,
@@ -133,10 +127,8 @@ test_that("Creating Landsat cubes from MPC", {
         multicores = 1,
         progress = FALSE
     ))
-    expect_equal(.tile_nrows(.tile(rg_landsat)), 856)
-    expect_equal(.tile_ncols(.tile(rg_landsat)), 967)
 
-    expect_true(.check_cube_is_regular(rg_landsat))
+    expect_true(.cube_is_regular(rg_landsat))
 
     l5_cube <- .try(
         {
@@ -145,6 +137,7 @@ test_that("Creating Landsat cubes from MPC", {
                 collection = "LANDSAT-C2-L2",
                 platform = "LANDSAT-5",
                 roi = bbox,
+                crs = 4326,
                 bands = c("NIR08", "CLOUD"),
                 start_date = as.Date("2008-07-18"),
                 end_date = as.Date("2008-10-23"),
@@ -184,21 +177,19 @@ test_that("Regularizing local cubes without CLOUD BAND", {
         dir.create(output_dir)
     }
     # regularize local cube
-    expect_warning({
-        local_reg_cube <- sits_regularize(
-            cube = local_cube,
-            period = "P2M",
-            res = 500,
-            output_dir = output_dir,
-            progress = FALSE
-        )
-    })
+    local_reg_cube <- suppressWarnings(sits_regularize(
+        cube = local_cube,
+        period = "P2M",
+        res = 500,
+        output_dir = output_dir,
+        progress = FALSE
+    ))
     tl_orig <- sits_timeline(local_cube)
     tl_reg <- sits_timeline(local_reg_cube)
 
     fi_reg <- .fi(local_reg_cube)
     r_obj_reg <- .raster_open_rast(fi_reg$path[[1]])
-    values_reg <- terra::values(r_obj_reg)
+    values_reg <- .raster_values_mem(r_obj_reg)
     # check there are no NAs
     expect_equal(length(which(is.na(values_reg))), 0)
     # check interval is two months
@@ -208,3 +199,110 @@ test_that("Regularizing local cubes without CLOUD BAND", {
     )
     expect_equal(lubridate::time_length(int, "month"), 2)
 })
+
+
+test_that("roi handling in regularization", {
+    # creating an irregular data cube from AWS
+    s2_cube <- .try(
+        {
+            sits_cube(
+                source = "AWS",
+                collection = "SENTINEL-2-L2A",
+                tiles = c("20LKP", "20LLP"),
+                bands = c("B02"),
+                start_date = as.Date("2018-06-30"),
+                end_date = as.Date("2018-08-31"),
+                progress = FALSE
+            )
+        },
+        .default = NULL
+    )
+
+    testthat::skip_if(purrr::is_null(s2_cube),
+                      message = "AWS is not accessible"
+    )
+
+    # create directory
+    output_dir <- paste0(tempdir(), "/images_roi_handling_test")
+    if (!dir.exists(output_dir)) {
+        dir.create(output_dir)
+    }
+
+    # case 1: roi with no intersection with the cube
+    no_intersecting_roi <- c(
+        xmin = -48.28579, ymin = -16.05026,
+        xmax = -47.30839, ymax = -15.50026
+    )
+
+    expect_error(
+        suppressWarnings(
+            sits_regularize(
+                cube = s2_cube,
+                period = "P3M",
+                res = 500,
+                output_dir = output_dir,
+                progress = FALSE,
+                roi = no_intersecting_roi
+            )
+        )
+    )
+
+    # case 2: roi intersecting only one tile
+    one_tile_roi <- c(
+        xmin = -64.27607,
+        ymin = -10.48214,
+        xmax = -64.19867,
+        ymax = -10.41729
+    )
+
+    s2_cube_reg <- suppressWarnings(
+        sits_regularize(
+            cube = s2_cube,
+            period = "P3M",
+            res = 500,
+            output_dir = output_dir,
+            progress = FALSE,
+            roi = one_tile_roi
+        )
+    )
+
+    # test cube properties
+    expect_equal(nrow(s2_cube_reg), 1)
+    expect_true(s2_cube_reg[["tile"]] == s2_cube[1,][["tile"]])
+
+    # delete files
+    unlink(list.files(output_dir,
+                      pattern = "\\.tif$",
+                      full.names = TRUE
+    ))
+})
+test_that("Regularize and convert grid system",{
+    # create an RTC cube from MPC collection for a region in Mato Grosso, Brazil.
+    cube_s2 <-  sits_cube(
+        source = "MPC",
+        collection = "SENTINEL-2-L2A",
+        bands = c("B08", "CLOUD"),
+        tiles = c("22LBL"),
+        start_date = "2021-06-01",
+        end_date = "2021-06-30"
+    )
+
+    # define the output directory
+    tempdir_r <- file.path(tempdir(), "reg_bdc")
+
+    # set output dir if it does not exist
+    dir.create(tempdir_r, showWarnings = FALSE)
+
+    # create a regular RTC cube from MPC collection for a tile 22LBL.
+    cube_reg <- suppressWarnings(sits_regularize(
+        cube = cube_s2,
+        period = "P15D",
+        res = 100,
+        grid_system = "BDC_SM_V2",
+        memsize = 12,
+        multicores = 6,
+        output_dir = tempdir_r
+    ))
+    expect_true(all(cube_reg[["tile"]] %in%
+                        c("022019", "022020", "023019", "023020")))
+})
